@@ -3,7 +3,7 @@
 import sys
 import os
 
-sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../build")
+sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)) + "/../build")
 
 from pywpsrpc.rpcwpsapi import (createWpsRpcInstance, wpsapi)
 from pywpsrpc.common import FAILED
@@ -38,10 +38,6 @@ def main():
 
     doc.Close(SaveChanges=wpsapi.wdDoNotSaveChanges)
 
-    doc = app.ActiveDocument
-    print(app.last_error)
-
-    app.use_exception = True
     try:
         # should be failed since no Documents opened.
         doc = app.ActiveDocument
